@@ -44,12 +44,11 @@ export FORY_CI=true
 install_python() {
   wget -q https://repo.anaconda.com/miniconda/Miniconda3-py38_23.5.2-0-Linux-x86_64.sh -O Miniconda3.sh
   bash Miniconda3.sh -b -p $HOME/miniconda && rm -f miniconda.*
-  which python
-  echo "Python version $(python -V), path $(which python)"
+  echo "$(python -V), path $(which python)"
 }
 
 install_pyfory() {
-  echo "Python version $(python -V), path $(which python)"
+  echo "$(python -V), path $(which python)"
   "$ROOT"/ci/deploy.sh install_pyarrow
   pip install Cython wheel pytest
   pushd "$ROOT/python"
@@ -90,15 +89,15 @@ install_bazel() {
   esac
 
   BAZEL_VERSION=$(get_bazel_version)
-  BAZEL_DIR="/usr/local/bin"
+  BAZEL_DIR="$HOME/.local/bin"
+  mkdir -p "$BAZEL_DIR"
 
   # Construct platform-specific URL
   BINARY_URL="https://github.com/bazelbuild/bazel/releases/download/${BAZEL_VERSION}/bazel-${BAZEL_VERSION}-${OS}-${ARCH}"
 
   echo "Downloading bazel from: $BINARY_URL"
-  sudo wget -q -O "$BAZEL_DIR/bazel" "$BINARY_URL" || { echo "Failed to download bazel"; exit 1; }
-
-  sudo chmod +x "$BAZEL_DIR/bazel"
+  curl -L -sSf -o "$BAZEL_DIR/bazel" "$BINARY_URL" || { echo "Failed to download bazel"; exit 1; }
+  chmod +x "$BAZEL_DIR/bazel"
 
   # Add to current shell's PATH
   export PATH="$BAZEL_DIR:$PATH"
@@ -108,7 +107,7 @@ install_bazel() {
   bazel version || { echo "Bazel installation verification failed"; exit 1; }
 
   # Configure number of jobs based on memory
-  if [[ "$MACHINE" == linux ]]; then
+  if [[ "$OS" == linux ]]; then
     MEM=$(grep MemTotal < /proc/meminfo | awk '{print $2}')
     JOBS=$(( MEM / 1024 / 1024 / 3 ))
     echo "build --jobs=$JOBS" >> ~/.bazelrc
